@@ -16,7 +16,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 #
 # ------------------------------------------------------------------------------------------------------- structural methods -----
@@ -79,7 +79,7 @@ sub get_entry {
 			return($val);
 		}
 	}else{
-		return undef;
+		return (wantarray ? () : undef);
 	}
 }
 
